@@ -155,7 +155,7 @@ impl<'a> SeqFilter<'a> {
         output_fmt: &OutputFmt,
         part_fmt: &PartitionFmt,
     ) {
-        let concat = MSAlignment::new(self.input_fmt, self.output, output_fmt, part_fmt);
+        let mut concat = MSAlignment::new(self.input_fmt, self.output, output_fmt, part_fmt);
         concat.concat_alignment(ftr_files, self.datatype);
     }
 
